/*
 *	gen_pulse.c
 *
 *	C Version 1.6 by Steve Sampson, Public Domain, 15 August 1988
 *
 *	This program is used to generate time domain pulse data	for fft.c.
 *
 *	Usage: gen_pulse samples output
 */

#include <stdio.h>
#include <malloc.h>

#define	Chunk	((unsigned)(samples * sizeof(double)))

#ifdef	SYSV
#define	WMODE	"w"
#else
#define	WMODE	"wb"
#endif

static double	sample, pw, time, *real, *imag;
static int	loop, samples;
static void	err_report();
static FILE	*fp;


main(argc, argv)
int	argc;
char	*argv[];
{
	if (argc != 3)
		err_report(0);

	samples = abs(atoi(argv[1]));

	if ((real = (double *)malloc(Chunk)) == (double *)NULL)
		err_report(1);

	if ((imag = (double *)malloc(Chunk)) == (double *)NULL)
		err_report(2);

	printf("Input The Pulse Width (Seconds) ? ");
	scanf("%lf", &pw);
	printf("Input The Sampling Time (Seconds) ? ");
	scanf("%lf", &sample);

	time = (double)0.0;
	for (loop = 0; loop < samples; loop++)  {
		if (time < pw)
			real[loop] = (double)1.0;
		else
			real[loop] = (double)0.0;

		imag[loop] = (double)0.0;
		time += sample;
	}

	if ((fp = fopen(argv[2], WMODE)) == (FILE *)NULL)
		err_report(3);

	fwrite((char *)real, sizeof(double), (unsigned)samples, fp);
	fwrite((char *)imag, sizeof(double), (unsigned)samples, fp);
	fclose(fp);

	putchar('\n');

	free((char *)real);
	free((char *)imag);

	exit(0);
}


static void err_report(n)
int	n;
{
	switch (n)  {
	case 0:
		fprintf(stderr,"Usage: gen_pulse samples output_file\n");
		fprintf(stderr,"Where samples is a power of two\n");
		break;
	case 1:
		fprintf(stderr,"gen_pulse: Out of memory getting real space\n");
		break;
	case 2:
		fprintf(stderr,"gen_pulse: Out of memory getting imag space\n");
		free((char *)real);
		break;
	case 3:
		fprintf(stderr,"gen_pulse: Unable to create write file\n");
	}

	exit(1);
}

/* EOF */
